==> haskell-here-1.2.13-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-4N02l6iR1pfE4PGvZCqLPw
key: here-1.2.13-4N02l6iR1pfE4PGvZCqLPw
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 07d8055ff68e6e4cf34febd803a89f1b
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/here-1.2.13
hs-libraries: HShere-1.2.13-4N02l6iR1pfE4PGvZCqLPw
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-2ZnWbpI5fKX7AzfNfuipe2
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-meta-0.8.0.3-2ZnWbpI5fKX7AzfNfuipe2=0239169cea56d5906d094c8741f7972c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.13-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: here
version: 1.2.13
id: here-1.2.13-312NWoqVf3ACSFHbIGKYP9
key: here-1.2.13-312NWoqVf3ACSFHbIGKYP9
license: BSD-3-Clause
copyright: ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer: t@tmh.cc
author: Taylor M. Hedberg
homepage: https://github.com/tmhedberg/here
synopsis: Here docs & interpolated strings via quasiquotation
description:
    Here docs & interpolated strings via quasiquotation
category: Data
abi: 0ddd33879170bd9706bc104e7c150c38
exposed: True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated
hidden-modules: Data.String.Here.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/here-1.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/here-1.2.13
hs-libraries: HShere-1.2.13-312NWoqVf3ACSFHbIGKYP9
depends:
    base-4.11.1.0 haskell-src-meta-0.8.0.3-9PcsUu8R82bLJZqCm1DPVL
    mtl-2.2.2 parsec-3.1.13.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-meta-0.8.0.3-9PcsUu8R82bLJZqCm1DPVL=8c1541ecc4e2bace16557a530c3f24b0
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-here/html/here.haddock
haddock-html: /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
